@@ -29,6 +29,8 @@ class Synapse(ABC):
     def __set_request(self):
         if self.request_type == RequestType.DESCRIBE:
             return DescribeRequest.parse_obj(self.raw_request.body)
+        elif self.request_type in [RequestType.GET_ACCESS_TOKEN]:
+            return OAuthRequest.parse_obj(self.raw_request.body)
         elif self.request_type in [RequestType.READ, RequestType.GET_BY_ID, RequestType.CREATE, RequestType.UPDATE, RequestType.DELETE]:
             return SyncRequest.parse_obj(self.raw_request.body)
         elif self.request_type in [RequestType.EXTRACT_WEBHOOK_IDENTIFIER, RequestType.PROCESS_WEBHOOK]:
@@ -36,6 +38,23 @@ class Synapse(ABC):
         else:
             return self.raw_request
 
+    def __get_access_token(self, oauth_request: OAuthRequest) -> dict:
+        resp = dict()
+        resp['grant_type'] = 'authorization_code'
+        resp['code'] = oauth_request.code
+        resp['client_id'] = oauth_request.authConfig.clientId
+        resp['client_secret'] = oauth_request.authConfig.clientSecret
+        resp['redirect_uri'] = oauth_request.redirectUri
+        return resp
+
+    def __refresh_token(self, connection: Connection) -> dict:
+        resp = dict()
+        resp['grant_type'] = 'refresh_token'
+        resp['refresh_token'] = connection.authConfig.refreshToken
+        resp['client_id'] = connection.authConfig.clientId
+        resp['client_secret'] = connection.authConfig.clientSecret
+        return resp
+
     def execute(self):
         """
             The route method that looks for the type of the synapse request and invokes
@@ -75,6 +94,22 @@ class Synapse(ABC):
                 if not isinstance(response, ReadResponse):
                     raise self.__prep_invalid_response_exception(response)
 
+            elif self.request_type == RequestType.GET_ACCESS_TOKEN:
+                if hasattr(self, "get_access_token") and callable(self.get_access_token):
+                    response = self.get_access_token(self.request)
+                else:
+                    response = self.__get_access_token(self.request)
+                if not isinstance(response, dict):
+                    raise self.__prep_invalid_response_exception(response)
+
+            elif self.request_type == RequestType.REFRESH_TOKEN:
+                if hasattr(self, "refresh_token") and callable(self.refresh_token):
+                    response = self.refresh_token(self.connection)
+                else:
+                    response = self.__refresh_token(self.connection)
+                if not isinstance(response, dict):
+                    raise self.__prep_invalid_response_exception(response)
+
             elif self.request_type == RequestType.GET_BY_ID:
                 response = self.get_by_id(self.request)
                 if not isinstance(response, list):
