@@ -37,17 +37,8 @@ def test_get_exception():
     try:
         resp = rest_client.get('search?country=United+States')
     except SyncariException as e:
-        assert e.error_response.status_code == 400
+        assert e.error_response.status_code == 500
         assert e.error_response.message == 'Failed to execute GET on url:http://universities.hipolabs.comsearch?country=United+States'
     except Exception as e:
         fail('Invalid exception thrown from SyncariRestClient')
 
-@pytest.mark.skip(reason="Token expired")
-def test_post():
-    rest_client = SyncariRestClient('https://api.provarity.com/', None)
-    auth_data = {'user':'customer+syncari_admin@provarity.com', 'pass':'U3luY2FyaTF8Y3VzdG9tZXIrc3luY2FyaV9hZG1pbkBwcm92YXJpdHkuY29t'}
-    resp = rest_client.post('user/login/provarity', json=auth_data)
-    assert resp.status_code == 200
-    resp_json = resp.json()
-    resp_token_key = resp.json()['token']['key']
-    assert resp_token_key is not None
